#
# spec file for package libgtop
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 11
Name:           libgtop
Version:        2.41.3+4
Release:        1.3
Summary:        System status information library
License:        GPL-2.0-or-later
Group:          Development/Libraries/C and C++
URL:            https://developer.gnome.org/libgtop/stable/
Source:         %{name}-%{version}.tar.zst
BuildRequires:  gobject-introspection-devel
BuildRequires:  gtk-doc
BuildRequires:  libtool
BuildRequires:  makeinfo
BuildRequires:  pkgconfig
BuildRequires:  util-linux-systemd
BuildRequires:  pkgconfig(glib-2.0) >= 2.6.0
BuildRequires:  pkgconfig(gobject-2.0) >= 2.26.0
BuildRequires:  pkgconfig(xau)
PreReq:         permissions

%description
A library that fetches information about the running system, such as
CPU and memory usage and active processes.

On Linux systems, this information is taken directly from the /proc
file system. On other systems, a server is used to read information
from /dev/kmem.

%package -n libgtop-2_0-%{sover}
Summary:        System status information library
Group:          System/Libraries
# Needed to make lang package installable
Provides:       %{name} = %{version}
Obsoletes:      %{name} < %{version}
#

%description -n libgtop-2_0-%{sover}
A library that fetches information about the running system, such as
CPU and memory usage and active processes.

On Linux systems, this information is taken directly from the /proc
file system. On other systems, a server is used to read information
from /dev/kmem.

%package -n typelib-1_0-GTop-2_0
Summary:        Introspection bindings for libgtop
Group:          System/Libraries

%description -n typelib-1_0-GTop-2_0
A library that fetches information about the running system, such as
CPU and memory usage and active processes.

On Linux systems, this information is taken directly from the /proc
file system. On other systems, a server is used to read information
from /dev/kmem.

This package provides the GObject Introspection bindings for libgtop.

%package devel
Summary:        Development files for libgtop
Group:          Development/Libraries/GNOME
Requires:       libgtop-2_0-%{sover} = %{version}
Requires:       typelib-1_0-GTop-2_0 = %{version}
# FIXME: use proper Requires(pre/post/preun/...)
#
PreReq:         %{install_info_prereq}

%description devel
This package contains all necessary include files and libraries needed
to develop applications that require these.

%package doc
Summary:        Documentation for the libgtop library
Group:          Development/Libraries/GNOME
Requires:       libgtop-2_0-%{sover} = %{version}
# FIXME: use proper Requires(pre/post/preun/...)
PreReq:         /sbin/install-info
BuildArch:      noarch

%description doc
A library that fetches information about the running system, such as
CPU and memory usage and active processes.

On Linux systems, this information is taken directly from the /proc
file system. On other systems, a server is used to read information
from /dev/kmem.

%lang_package

%prep
%autosetup -p1

%build
NOCONFIGURE=1 ./autogen.sh
%configure\
	--disable-static
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
%find_lang %{name} %{?no_lang_C}

%ldconfig_scriptlets -n libgtop-2_0-%{sover}

%preun doc
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}2.info.gz

%post doc
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}2.info.gz

%post
%set_permissions /usr/libexec/libgtop_server2

%verifyscript
%verify_permissions -e /usr/libexec/libgtop_server2

%files lang -f %{name}.lang

%files
%{_libexecdir}/libgtop_server2
%{_libexecdir}/libgtop_daemon2

%files -n libgtop-2_0-%{sover}
%license COPYING
%doc AUTHORS NEWS README copyright.txt
%{_libdir}/*.so.*

%files -n typelib-1_0-GTop-2_0
%{_libdir}/girepository-1.0/GTop-2.0.typelib

%files devel
%{_includedir}/libgtop-2.0
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_datadir}/gir-1.0/GTop-2.0.gir

%files doc
%{_infodir}/*.info*

%changelog
* Thu Sep 26 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.41.3+4:
  + Reproducible Builds: Do not embed build-server kernel version
    on Linux (boo#1230850).
  + Updated translations.
* Mon Feb 19 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 2.41.3:
  + Fixed daemon buffer overflow.
  + Updated translations.
* Tue Jan 16 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Convert to source service for easier updating.
- Add libtool, gtk-doc, makeinfo and util-linux-systemd
  BuildRequires and call autogen.sh: git checked out sources are
  not bootstrapped.
* Sun Oct 15 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.41.2:
  + Change disk example read/write unit to bytes
  + Fixed potential Buffer overflow when reading disk stats
  + Changed disk read/write unit to bytes in example
- Changes from version 2.41.1:
  + Skip loop and rom devices
  + Allow building with gettext >= 0.20
  + Updated translations.
- Replace glib2-devel with pkgconfig(glib-2.0) BuildRequires: Align
  with what configure checks for.
- Use autosetup and ldconfig_scriptlets macros.
- Build the doc sub-package as noarch.
- Add permissions PreReq and set_permissions and verify_permissions
  macros in post and verifyscript sections.
* Mon Dec 19 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Drop baselibs.conf: there is no known consumer of the -32bit
  package.
* Thu Sep 16 2021 Stanislav Brabec <sbrabec@suse.com>
- Remove obsolete translation-update-upstream support
  (jsc#SLE-21105).
* Sat Jan 25 2020 Dominique Leuenberger <dimstar@opensuse.org>
- No longer recommend -lang: supplements are in use
* Mon Mar 11 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 2.40.0:
  + Fixed array and transfer annotations for documentation.
* Mon Feb 18 2019 bjorn.lie@gmail.com
- Update to version 2.39.91:
  + Replace deprecated gnome-common with autoreconf.
* Thu Feb 14 2019 bjorn.lie@gmail.com
- Update to version 2.39.90:
  + Fixed compile warnings
  + Linux: Get procmap doesn't need suid.
  + Updated translations.
* Tue Mar 20 2018 dimstar@opensuse.org
- Unconditionally enable translation-update-upstream: on
  Tumbleweed, this results in a NOP and for Leap in SLE paid
  translations being used (boo#1086036).
* Wed Feb 28 2018 dimstar@opensuse.org
- Modernize spec-file by calling spec-cleaner
* Mon Sep 11 2017 zaitor@opensuse.org
- Update to version 2.38.0:
  + Updated translations.
* Wed Sep  6 2017 dimstar@opensuse.org
- Update to version 2.37.92:
  + Code cleanup.
  + Updated translations.
* Mon Aug 14 2017 zaitor@opensuse.org
- Update to version 2.37.90:
  + Added reserved fields to the sysdeps struct.
  + Fixed build failure in FreeBSD 11.
  + Updated translations.
* Tue May 23 2017 zaitor@opensuse.org
- Update to version 2.37.2:
  + Added support for per-process io monitoring.
  + Added nullpointer check.
  + Use unicode in translatable strings.
  + Updated translations.
- Bump soname and baselibs.conf following upstream changes.
- Drop libgtop-add-NULL-pointer-checker.patch: Fixed upstream.
* Tue May 23 2017 zaitor@opensuse.org
- Add libgtop-add-NULL-pointer-checker.patch: Add NULL pointer
  checker (bug found with scan-build). Patch from upstream stable
  git branch.
* Tue Mar 21 2017 dimstar@opensuse.org
- Update to version 2.36.0:
  + No changes.
* Tue Mar 14 2017 zaitor@opensuse.org
- Update to version 2.35.92:
  + Better output format for arrays.
* Thu Mar  2 2017 jengelh@inai.de
- Rename %%soname to %%sover to better reflect its use.
- Redo summaries and RPM groups.
* Wed Feb 15 2017 dimstar@opensuse.org
- Update to version 2.35.90:
  + Use dynamically allocated cpu buffer.
  + Do not cache getpagesize().
  + Use faster g_ascii_isspace in tokenization.
  + Ignore paragraphs not describing a CPU/core.
  + Updated translations.
- Drop libgtop-bsc1020294-cpu-buffer.patch: fixed upstream.
- Drop fdupes BuildRequires: it's already not been started and
  rpmlint also does not complain about duplicate files.
* Thu Jan 19 2017 mgorse@suse.com
- Add libgtop-bsc1020294-cpu-buffer.patch: dynamically allocate
  memory for buffer when reading /proc/cpuinfo (bsc#1020294
  bgo#323354).
* Mon Jan 16 2017 zaitor@opensuse.org
- Update to version 2.34.2:
  + Linux: fill last_processor member.
  + Added more gettext options.
  + Updated translations.
- Add url to upstream developer page, silence rpmlint.
* Thu Dec  1 2016 dimstar@opensuse.org
- Fix build on SLE: pass "po libgtop" to
  translation-update-upstream: it fails do detect the correct
  gettext domain.
* Sat Aug 20 2016 zaitor@opensuse.org
- Update to version 2.34.1:
  + Rename --with-libgtop-examples to --with-examples.
  + Use gettext instead of intltool/glib-gettext.
  + Added Language headers to the translations.
- Drop intltool BuildRequires following upstream changes.
- Remove obsolete clean section, and conditionals for long gone
  versions of openSUSE.
- Make translation-update-upstream conditional, only apply on
  non-openSUSE.
* Fri Apr 15 2016 mgorse@suse.com
- Update to GNOME 3.20  Fate#318572
- Drop extending-max-cpu-number.patch: fixed upstream.
  (bnc#885202).
* Tue Mar 22 2016 dimstar@opensuse.org
- Update to version 2.34.0:
  + Stable release.
* Tue Mar  1 2016 zaitor@opensuse.org
- Update to version 2.33.91:
  + Fix building on musl-libc.
  + Updated translations.
- Drop libgtop_spec-update.sh as source, and clean spec of it. No
  longer needed in the obs.
- Move %%install_info_delete for doc subpackage from postun to
  preun.
* Wed Jan 20 2016 dimstar@opensuse.org
- Update to version 2.33.4:
  + On OpenBSD only PID 1 is special.
  + Call setlocale in main.
* Tue Dec 22 2015 zaitor@opensuse.org
- Update to version 2.33.3:
  + Fixed broken compilation on OpenBSD.
  + Updated translations.
* Tue Sep 22 2015 dimstar@opensuse.org
- Update to version 2.32.0:
  + Stable release.
* Wed Sep 16 2015 dimstar@opensuse.org
- Update to version 2.31.91:
  + Darwin: Fixed build.
  + All:
  - GI docs fixes.
  - include fixes.
  + Updated translations.
* Mon Aug 17 2015 zaitor@opensuse.org
- Update to version 2.31.90:
  + ABI changes:
  - ABI was inconsistent on platforms like FreeBSD which make use
    of glibtop_machine. The ABI was actually different between
    the library and the server. Fixed this by simply always
    defining glibtop_machine in glibtop struct.
  - Add Pss and Swap members in glibtop_proc_mem.
  - This is the second ABI breakage in since 2.28 (the first one
    was bumping NCPU), there were no release for 2.30.
  + FreeBSD:
  - proclist: exclude the "idle" kernel process when
    GLIBTOP_EXCLUDE_IDLE.
  - Remove extraneous glibtop_init() calls.
  + Linux:
  - proc_mem: implement Pss and Swap.
  - Remove extraneous glibtop_init() calls.
  + All:
  - Propagate the change that machine in struct glibtop is now a
    pointer. Hope that change doesn't break build on other
    platforms, I can only test Linux and FreeBSD.
* Thu Aug  6 2015 zaitor@opensuse.org
- Update to version 2.31.4:
  + Implement a proper --enable-debug mode.
  + FreeBSD:
  - procstate: set process name for kernel (pid=0).
  - procmap: get dev/inode for ZFS (no filename yet).
  - mem: rework memory usage to something more meaningful.
  - proclist: don't report threads.
  - proctime: fix CPU times.
  + Linux:
  - mem:
    . Use MemAvailable when available.
    . Match `free`, report Slab as Cached.
  - Support for x.y versionsmemory to match `free`.
  + Fix a lot of GI tags: it now works without crashing.
  + Server and daemon binaries are now dynamically linked against
    their libgtop.
  + Update a lot of examples/.
  + Clean up some very old code.
  + Updated translations.
* Fri Jun 26 2015 zaitor@opensuse.org
- Update to version 2.31.3:
  + Numerous OpenBSD backend fixes.
  + Fixed FreeBSD build issues.
  + Implemented procaffinity support for NetBSD.
  + Updated translations.
- Add pkgconfig(glib-2.0) BuildRequires: New explicit dependency.
* Wed Oct  1 2014 crrodriguez@opensuse.org
- Replace xorg-x11-devel BuildRequires with pkgconfig(xau): there
  is no need for the whole metapackage.
* Thu Jul  3 2014 mgorse@suse.com
- Add extending-max-cpu-number.patch: support more than 32 CPUs
  (bnc#885202).
- Adjust package name, since the patch introduces an ABI break.
* Wed Apr 30 2014 dimstar@opensuse.org
- Update to version 2.30.0:
  + Fixed libtool versioning for ABI breakage.
  + Removed useless override for LINK variable.
  + Fixed FTBFS on kFreeBSD.
- Change the name of libgtop-2_0_name defines to soname, and
  actually use it. Bump from 7 to 10, following upstreams soname
  change. Also update baselibs.conf to reflect the new soname.
- Remove the check for the library name in the install section:
  this is rpmlints job.
* Mon Aug 19 2013 dimstar@opensuse.org
- Update to version 2.28.5:
  + Fix numerous bugs in the OpenBSD backend.
  + Updated translations.
* Fri Dec 23 2011 vuntz@opensuse.org
- Split typelib file into typelib-1_0-GTop-2_0 subpackage.
- Add typelib-1_0-GTop-2_0 Requires to devel subpackage.
- Change group of main subpackage and libgtop-2_0-7 to
  System/Libraries.
* Tue Aug 30 2011 vuntz@opensuse.org
- Update to version 2.28.4:
  + Fix numerous bugs in the FreeBSD backend.
  + Split off OpenBSD code in its own backend, and fixes.
  + Updated translations.
- Stop shipping .la files in devel subpackage.
* Mon Mar 28 2011 fcrozat@novell.com
- Update to version 2.28.3:
  + Fix build issue for strict linkers.
  + Add Introspection support
  + Updated translations.
- Add gobject-introspection-devel to BuildRequires, to enable
  introspection.
* Mon Mar 21 2011 coolo@novell.com
- licenses package is about to die
* Mon Oct 11 2010 vuntz@opensuse.org
- Remove libgtop package that was empty, and add Provides/Obsoletes
  for it to libgtop-2_0-7. Also move the Requires of the lang
  package there, as a Recommends.
- Remove unneeded Requires of devel package: glib2-devel,
  gdbm-devel, xorg-x11-devel. Only glib2-devel was really needed,
  and it will be added automatically via the pkgconfig() way.
* Tue Sep 28 2010 vuntz@opensuse.org
- Update to version 2.28.2:
  + Updated translations.
* Tue Mar 30 2010 vuntz@opensuse.org
- Update to version 2.28.1:
  + Updated translations.
- Remove en@shaw translations on 11.2 and earlier.
* Mon Feb  1 2010 jengelh@medozas.de
- Package baselibs.conf
* Wed Dec  2 2009 vuntz@opensuse.org
- Update the way we remove the la locale for old versions of
  openSUSE.
* Tue Sep 22 2009 dimstar@opensuse.org
- Update to version 2.28.0:
  + Updated translations.
* Wed May 27 2009 vuntz@novell.com
- Update to version 2.27.3:
  + linux:
  - fixed format error.
* Tue May  5 2009 vuntz@novell.com
- Update to version 2.27.2:
  + linux:
  - glibtop_get_proc_map: oops, fixed segfault.
- Changes from version 2.27.1:
  + linux:
  - glibtop_get_proc_map is ~40%% faster. This should be
    noticeable in system-monitor.
  + New cygwin support.
* Tue Apr 14 2009 vuntz@novell.com
- Update to version 2.26.1:
  + linux:
  - glibtop_get_mounlist(...): also hide "none" fs.
* Mon Mar 16 2009 sbrabec@suse.cz
- Added support for translation-update-upstream (FATE#301344).
* Mon Mar  2 2009 mboman@suse.de
- Update to version 2.26.0:
  + Cosmetic version bump
- Move gtk-doc to -devel package
* Wed Feb 18 2009 mboman@suse.de
- Exclude locale/la on <= 1110
* Tue Feb 17 2009 vuntz@novell.com
- Update to version 2.25.91:
  + Single glib.h include.
  + Fixed Darwin build. (bgo#556904).
  + Updated translations.
- Remove BuildRequires: gdbm-devel, popt-devel.
* Mon Feb  2 2009 mboman@suse.de
- Update to version 2.24.4:
  + Fixed license: libgtop is GPL-2
  + fixed potential memory leak
  + fixed read(2) usage. Should fix the missing cpus bug in system-monitor
- Remove libgtop-fsusage-leak.patch. Fixed upstream
* Tue Jan 13 2009 olh@suse.de
- add PreReq info to libgtop to help solver during libgtop upgrade
* Wed Jan  7 2009 olh@suse.de
- obsolete old -XXbit packages (bnc#437293)
* Mon Jan  5 2009 vuntz@novell.com
- Add libgtop-fsusage-leak.patch to fix a potential leak. Fix
  bnc#460758.
* Tue Sep 23 2008 maw@suse.de
- Update to version 2.24.0:
  + Updated translations.
* Sun Aug 24 2008 mboman@novell.com
- Updated to version 2.23.90:
  * freebsd: Updated port by Joe Marcus Clarke.
* Tue Aug 12 2008 captain.magnus@opensuse.org
- Updated to version 2.23.4:
  + Fixed and improved glibtop_get_fsusage with kernel >= 2.6.25.
    Closes bgo#539360.
* Tue Jun 17 2008 aj@suse.de
- Do not build require gtk-doc.
* Mon Jun 16 2008 maw@suse.de
- Update to version 2.23.2:
  + glibtop_get_proc_open_files API can also lists IPv6 TCP sockets
  + glibtop_get_proc_affinity : new API to retrieve process CPU
    affinity
  + Fixed parsing of big /proc/stat for uptime
- Remove stale patches: gnome-system-monitor-resident-schema.patch
  and libgtop-bnc386735.patch.
* Mon May 12 2008 hfiguiere@suse.de
- added libgtop-bnc386735.patch to fix bnc#386735.
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Wed Apr  9 2008 maw@suse.de
- Update to version 2.22.1:
  + Bug fixed: bgo#525953.
* Fri Mar 14 2008 maw@suse.de
- Update to version 2.22.0:
  + Fixed proc_kernel.
* Tue Mar  4 2008 maw@suse.de
- Update to version 2.21.92:
  + Fixed smaps parsing on linux kernels >= 2.6.24.x.
* Wed Jan 30 2008 rodrigo@suse.de
- Update to version 2.21.5:
  * Fixed build on GNU/kfreebsd
  * Fixed procmem units
* Thu Dec 20 2007 jpr@suse.de
- Update to version 2.21.1
  * don't export _p/_s private symbols anymore. This is not an
    API/ABI breakage.
  * darwin implementation
  * linux:
  - splitted fsusage and mountlist implementations;
  - smarter mountlist(allfs = False);
  - fixed some compile warning on 64bit;
  * solaris:
  - fixed netload build
* Mon Sep 17 2007 sbrabec@suse.cz
- Updated to version 2.20.0:
  * updated translations
* Mon Sep 10 2007 maw@suse.de
- Update to version 2.19.92:
  + Fix hardwired path in linux/sysinfo.c.
* Tue Aug  7 2007 maw@suse.de
- Split off a -lang subpackage
- Use %%fdupes.
* Fri Aug  3 2007 mauro@suse.de
- Updated to version 2.19.5
- Small change of the API: get_proclist returns pid_t instead of unsigned
* Tue Jul 17 2007 sbrabec@suse.cz
- Fixed shared library packaging.
- Added script to update library package names.
* Mon Jul  9 2007 maw@suse.de
- Rename the package to libgtop-2_0-7
- Update to version 2.19.4
- Minor API change - get_proclist returns pit_t instead of unsigned
- Portability fixes.
* Mon Apr  2 2007 maw@suse.de
- Update to version 2.14.8
- Support for FreeBSD
- Fixed up signal handling.
* Mon Mar 26 2007 rguenther@suse.de
- Add gdbm-devel BuildRequires.
* Tue Feb 27 2007 maw@suse.de
- Create a -doc subpackage (#248813).
* Mon Feb 19 2007 maw@suse.de
- Update to version 2.14.7
- Remove libgtop-buffer-overflow.patch which is now upstream
- Package gtk-doc generated docs in the -devel subpackage.
* Tue Feb 13 2007 sbrabec@suse.cz
- Do not build unusable static libraries (#238552#c17).
* Fri Jan 19 2007 maw@suse.de
- Add libgtop-buffer-overflow.patch (#235086 and CVE-2007-0235).
* Mon Jan  8 2007 sbrabec@suse.cz
- Spec file cleanup.
* Sun Jan  7 2007 ro@suse.de
- GNOME moved to /usr
* Tue Oct  3 2006 jhargadon@suse.de
- update to version 2.14.4
- Fixed linux maps/smaps parsing on 64bit kernel
- Fixed build with --as-needed
- Added missing G_BEGIN_DECLS/G_END_DECLS
* Tue Aug 15 2006 jhargadon@suse.de
- update to version 2.14.2
- Updated solaris support
- interface addition to handle wireless interfaces.
* Tue Aug 15 2006 sbrabec@suse.cz
- Call ldconfig (#198912).
* Tue Aug  1 2006 gekker@suse.de
- Update to version 2.14.1
  * Updated translations.
  * Fixed NetBSD port (Julio M. Merino Vidal  <jmmv@NetBSD.org>).
  * Fixed proc_state documentation.
  * Updated mountlist ignore list.
  * fix get_procmap for linux < 2.6.14.
  * Fixed libtool versioning (James Henstridge)
  * fixed proclist
  * implemented server->real_ncpu
  * Requires automake-1.9 (James Henstridge)
  * Supports up to 32 CPU
  * Supports Linux smaps
  * fixed SMP detection
* Tue Mar 28 2006 joeshaw@suse.de
- Add a patch which makes the "Resident" field RSS - Shared,
  rather than just being a duplicate of RSS.  Fixes half of
  bnc #157022.  Submitted upstream as bgo #336376.
- Remove an unused, commented-out patch
* Sat Feb  4 2006 aj@suse.de
- Reduce BuildRequires.
* Thu Jan 26 2006 sbrabec@suse.cz
- Added %%install_info_prereq.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Nov 30 2005 gekker@suse.de
- Update to version 2.12.2
* Mon Sep  5 2005 gekker@suse.de
- Update to version 2.12.0 (GNOME 2.12)
* Tue Aug 23 2005 gekker@suse.de
- Update to version 2.11.92
* Mon Aug  8 2005 rodrigo@suse.de
- Updated to 2.11.91
* Tue Aug  2 2005 gekker@suse.de
- Update to version 2.11.90
- Fixup devel requirements
* Fri Jul 22 2005 gekker@suse.de
- Update to version 2.11.2
* Wed Jun 22 2005 gekker@suse.de
- Update to version 2.11.0
* Fri Jun 17 2005 sbrabec@suse.cz
- Build with libXau on x86_64 (#91187).
* Wed Jun  1 2005 sbrabec@suse.cz
- Fixed devel requirements.
* Wed Mar  9 2005 gekker@suse.de
- Update to version 2.10.0 (GNOME 2.10).
* Thu Mar  3 2005 gekker@suse.de
- Update to version 2.9.92
* Fri Feb 11 2005 gekker@suse.de
- Update to version 2.9.91
* Thu Jan 27 2005 hhetter@suse.de
- updated to version 2.9.90
* Mon Jan 24 2005 ro@suse.de
- fix build on x86_64 working around non-fPIC libXau
* Fri Jan 21 2005 gekker@suse.de
- Update to version 2.9.4
* Tue Jan  4 2005 gekker@suse.de
- Update to version 2.9.3
* Tue Dec 21 2004 gekker@suse.de
- Update to version 2.9.0
* Tue Nov 23 2004 ro@suse.de
- fix name of info file in postinstall
* Mon Oct 25 2004 ro@suse.de
- locale rename: no -> nb
* Thu Apr 29 2004 hhetter@suse.de
- updated to version 2.5.2 [GNOME2.6]
* Mon Mar 22 2004 sbrabec@suse.cz
- Provide and obsolete libgtop2-devel.
* Tue Mar 16 2004 sbrabec@suse.cz
- FHS 2.3 fix (mandir, infodir, #35821).
* Fri Feb 20 2004 sbrabec@suse.cz
- Package renamed to libgtop.
* Mon Feb 16 2004 hhetter@suse.de
- fix filelist
* Mon Feb  9 2004 hhetter@suse.de
- updated to version 2.0.8 [GNOME2.4.2]
* Thu Nov  6 2003 schwab@suse.de
- Fix quoting in configure script.
* Tue Sep  9 2003 sbrabec@suse.cz
- Updated to version 2.0.5.
* Mon Aug 25 2003 sbrabec@suse.cz
- Updated to version 2.0.4.
* Tue Aug 19 2003 sbrabec@suse.cz
- Updated to version 2.0.3.
* Mon Jul 14 2003 sbrabec@suse.cz
- GNOME prefix change to /opt/gnome.
* Thu Jun 26 2003 sbrabec@suse.cz
- Cleaned up neededforbuild.
- Use %%find_lang.
* Sun Jun 22 2003 ro@suse.de
- added gnome-filesystem to neededforbuild
- added directories to filelist
* Tue May 27 2003 sbrabec@suse.cz
- Updated to version 2.0.2.
- Updated neededforbuild.
- Fixed %%files.
* Thu Jan 16 2003 hhetter@suse.de
- updated to version 2.0.1
- adapted automake fix
* Tue Sep 24 2002 sbrabec@suse.cz
- Fixed incorrect update to 2.0.0.
* Tue Jun 11 2002 hhetter@suse.de
- updated to version 2.0.0
* Tue Jun  4 2002 hhetter@suse.de
- update to source frozen version 1.90.2
- fix filelist
* Wed May 15 2002 ro@suse.de
- use libdir
* Wed Apr 17 2002 ro@suse.de
- fix for automake-1.6
* Thu Jan 17 2002 hhetter@suse.de
- prefixed to /opt/gnome2
* Mon Jan 14 2002 hhetter@suse.de
- initial SuSE package for GNOME 2.0 platform
